from launchpadlib.launchpad import Launchpad
from launchpadlib.credentials import Credentials
from launchpadlib.errors import HTTPError

import sys
import os

def lp_login(lp_instance='production'):
    cachedir = os.path.abspath('lp_data/cache')
    creddir = os.getenv("CRED_DIR")
    if not creddir:
        creddir = os.path.abspath('lp_data/lp_credentials')
    
    if not os.path.isdir(creddir):
        os.makedirs(creddir)
    cred = os.path.join(creddir, 'sponsoring.credentials')
    if os.path.exists(cred):
        credentials = Credentials()
        credentials.load(open(cred))
        launchpad = Launchpad(credentials, lp_instance, cachedir)
    else:
        try:
            launchpad = Launchpad.get_token_and_login('sponsoring', 
                                lp_instance, cachedir)
        except HTTPError, e:
            print >> sys.stderr, 'Error connecting to Launchpad: %s' % str(e)
            sys.exit(1)
        f = open(cred, 'w')
        os.chmod(cred, 0600)
        launchpad.credentials.save(f)
        f.close()
    return launchpad


def get_packagesets(lp, distribution):
    """
    Get list of packagesets for current development release of Ubuntu and 
    the packages they include.
    """
    current_series = distribution.current_series
    packagesets = filter(lambda a: (a.distroseries == current_series) or \
                                   (a.distroseries.name == current_series.name) , lp.packagesets)
    packages = {}
    for packageset in packagesets:
        packages[packageset.name] = packageset.getSourcesIncluded()
    return packages

def person_can_upload(distribution, person, package_name):
    if distribution.main_archive.isSourceUploadAllowed(
            distroseries=distribution.current_series, person=person,
            sourcepackagename=package_name):
        return True
    pubs = distribution.main_archive.getPublishedSources(
            distro_series=distribution.current_series, exact_match=True,
            pocket="Release", status="Published", source_name=package_name)
    pubs = [pub for pub in pubs]
    if len(pubs) < 1:
        return False
    component = pubs[0].component_name
    for perm in distribution.main_archive.getPermissionsForPerson(person=person):
        if perm.permission != 'Archive Upload Rights':
            continue
        if perm.component_name == component:
            return True
        if perm.source_package_name == package_name:
            return True
    return False

